==> mahara_1.2.7.orig.tar.gz: mahara-1.2.7/htdocs/lang/en.utf8/export.php <==
<?php
/**
 * Mahara: Electronic portfolio, weblog, resume builder and social networking
 * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
 *                         http://wiki.mahara.org/Contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    mahara
 * @subpackage lang
 * @author     Catalyst IT Ltd
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
 * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
 *
 */

defined('INTERNAL') || die();

$string['allmydata'] = 'All my data';
$string['chooseanexportformat'] = 'Choose an export format';
$string['clicktopreview'] = 'Click to preview';
$string['creatingzipfile'] = 'Creating zipfile';
$string['Done'] = 'Done';
$string['Export']     = 'Export';
$string['exportgeneratedsuccessfully'] = 'Export generated successfully. %sClick here to download it%s';
$string['exportgeneratedsuccessfullyjs'] = 'Export generated successfully. %sContinue%s';
$string['exportingartefactplugindata'] = 'Exporting artefact plugin data';
$string['exportingartefacts'] = 'Exporting artefacts';
$string['exportingartefactsprogress'] = 'Exporting artefacts: %s/%s';
$string['exportingfooter'] = 'Exporting footer';
$string['exportingviews'] = 'Exporting Views';
$string['exportingviewsprogress'] = 'Exporting Views: %s/%s';
$string['exportpagedescription'] = 'Here you can export your portfolio. This tool exports all of your portfolio information and Views, but it does not export your site settings.';
$string['exportyourportfolio'] = 'Export Your Portfolio';
$string['generateexport'] = 'Generate export';
$string['noexportpluginsenabled'] = 'No export plugins have been enabled by the administrator, so you are unable to use this feature';
$string['justsomeviews'] = 'Just some of my Views';
$string['pleasewaitwhileyourexportisbeinggenerated'] = 'Please wait while your export is being generated...';
$string['setupcomplete'] = 'Setup complete';
$string['Starting'] = 'Starting';
$string['unabletoexportportfoliousingoptions'] = 'Unable to export a portfolio using the chosen options';
$string['unabletogenerateexport'] = 'Unable to generate export';
$string['viewstoexport'] = 'Views to export';
$string['whatdoyouwanttoexport'] = 'What do you want to export?';
$string['writingfiles'] = 'Writing files';
$string['youarehere'] = 'You are here';
$string['youmustselectatleastoneviewtoexport'] = 'You must select at least one View to export';
$string['zipnotinstalled'] = 'Your system does not have the zip command. Please install zip to enable this feature';

?>

==> mahara_1.4.0.orig.tar.gz: mahara-1.4.0/htdocs/lang/en.utf8/export.php <==
<?php
/**
 * Mahara: Electronic portfolio, weblog, resume builder and social networking
 * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
 *                         http://wiki.mahara.org/Contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    mahara
 * @subpackage lang
 * @author     Catalyst IT Ltd
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
 * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
 *
 */

defined('INTERNAL') || die();

$string['allmydata'] = 'All my data';
$string['chooseanexportformat'] = 'Choose an export format';
$string['clicktopreview'] = 'Click to preview';
$string['collectionstoexport'] = 'Collections to export';
$string['creatingzipfile'] = 'Creating zipfile';
$string['Done'] = 'Done';
$string['Export']     = 'Export';
$string['exportgeneratedsuccessfully'] = 'Export generated successfully. %sClick here to download it%s';
$string['exportgeneratedsuccessfullyjs'] = 'Export generated successfully. %sContinue%s';
$string['exportingartefactplugindata'] = 'Exporting artefact plugin data';
$string['exportingartefacts'] = 'Exporting artefacts';
$string['exportingartefactsprogress'] = 'Exporting artefacts: %s/%s';
$string['exportingfooter'] = 'Exporting footer';
$string['exportingviews'] = 'Exporting pages';
$string['exportingviewsprogress'] = 'Exporting pages: %s/%s';
$string['exportpagedescription'] = 'This tool exports all of your portfolio information and pages, but it does not export your site settings.';
$string['exportyourportfolio'] = 'Export Your Portfolio';
$string['generateexport'] = 'Generate export';
$string['noexportpluginsenabled'] = 'No export plugins have been enabled by the administrator, so you are unable to use this feature';
$string['justsomecollections'] = 'Just some of my Collections';
$string['justsomeviews'] = 'Just some of my pages';
$string['nonexistentfile'] = "Tried to add non-existent file: '%s'";
$string['pleasewaitwhileyourexportisbeinggenerated'] = 'Please wait while your export is being generated...';
$string['reverseselection'] = 'Reverse selection';
$string['selectall'] = 'Select all';
$string['setupcomplete'] = 'Setup complete';
$string['Starting'] = 'Starting';
$string['unabletoexportportfoliousingoptions'] = 'Unable to export a portfolio using the chosen options';
$string['unabletogenerateexport'] = 'Unable to generate export';
$string['viewstoexport'] = 'Pages to export';
$string['whatdoyouwanttoexport'] = 'What do you want to export?';
$string['writingfiles'] = 'Writing files';
$string['youarehere'] = 'You are here';
$string['youmustselectatleastonecollectiontoexport'] = 'You must select at least one collection to export';
$string['youmustselectatleastoneviewtoexport'] = 'You must select at least one page to export';
$string['zipnotinstalled'] = 'Your system does not have the zip command. Please install zip to enable this feature';
